==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-client/src/main/java/org/apache/hadoop/hbase/exceptions/FailedSanityCheckException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.exceptions;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;

/**
 * Exception thrown if a mutation fails sanity checks.
 */
@InterfaceAudience.Public
@InterfaceStability.Stable
public class FailedSanityCheckException extends org.apache.hadoop.hbase.DoNotRetryIOException {

  private static final long serialVersionUID = 1788783640409186240L;

  /**
   * default constructor
   */
  public FailedSanityCheckException() {
    super();
  }

  /**
   * @param message
   */
  public FailedSanityCheckException(String message) {
    super(message);
  }

  /**
   * @param message
   * @param cause
   */
  public FailedSanityCheckException(String message, Throwable cause) {
    super(message, cause);
  }

}

==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-client/src/main/java/org/apache/hadoop/hbase/exceptions/FailedSanityCheckException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.exceptions;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Exception thrown if a mutation fails sanity checks.
 */
@InterfaceAudience.Public
public class FailedSanityCheckException extends org.apache.hadoop.hbase.DoNotRetryIOException {

  private static final long serialVersionUID = 1788783640409186240L;

  /**
   * default constructor
   */
  public FailedSanityCheckException() {
    super();
  }

  /**
   * @param message
   */
  public FailedSanityCheckException(String message) {
    super(message);
  }

  /**
   * @param message
   * @param cause
   */
  public FailedSanityCheckException(String message, Throwable cause) {
    super(message, cause);
  }

}
